

local CustomClock = CustomClock;




do
	local ccFrame = CustomClock_DisplayFrame;
	
	ccFrame:RegisterEvent("VARIABLES_LOADED");
	ccFrame:RegisterEvent("PLAYER_LOGOUT");
	
	ccFrame.TEXT = CustomClock_DisplayFrameText;
	ccFrame.CUSTOMCLOCK = CustomClock;
	CustomClock.DISPLAY_FRAME = ccFrame;
	
	ccFrame.Elapsed = 0.0;
	CustomClock.SCRIPTS_FRAME = ccFrame;
end




function CustomClock:Main_UpdateDisplay()
	self.DISPLAY_FRAME.TEXT:SetText(date(self.Config.TimePattern));
end




function CustomClock:Main_OnEvent(event)
	if (event == "VARIABLES_LOADED") then
		self:Config_LoadSettings();
	elseif (event == "PLAYER_LOGOUT") then
		self:Config_SaveSettings();
	end
end


CustomClock.SCRIPTS_FRAME:SetScript("OnEvent", (function(self, event, ...) self.CUSTOMCLOCK:Main_OnEvent(event); end));




CustomClock.SCRIPTS_FRAME:SetScript("OnUpdate",
  function(self, elapsed)
	self.Elapsed = (self.Elapsed + elapsed);
	
	if (self.Elapsed > 0.9) then
		self.Elapsed = 0.0;
		
		self.CUSTOMCLOCK:Main_UpdateDisplay();
	end
  end
);




function CustomClock:Main_SlashCommandHandler(msg)
	local command, argument = msg:match("([^%s]+) (.+)");
	command = (command or msg):lower();
	
	local localization = self.LOCALIZATION;
	
	
	if (command == localization.SLASH_PATTERN) then
		if (argument ~= nil and argument ~= "") then
			local dateString = self:Config_SetDisplayPattern(argument);
			if (dateString ~= nil) then
				DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_PATTERN:format(argument), 0.6, 0.8, 0.6);
			else
				DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_PATTERN, 0.6, 0.8, 0.6);
			end
		else
			local chatFrame = DEFAULT_CHAT_FRAME;
			local addMessage = chatFrame.AddMessage;
			for index = 1, 23 do
				addMessage(chatFrame, localization["PATTERN_HELP_"..index], 0.6, 0.8, 0.6);
			end
			addMessage(chatFrame, localization.CURRENT_PATTERN:format(self.Config.TimePattern), 0.6, 0.8, 0.6);
		end
		
		
	elseif (command == localization.SLASH_COLOR) then
		local tonumber = tonumber;
		local mathceil = math.ceil;
		
		local redVal, greenVal, blueVal = (argument or ""):match("(%d+) (%d+) (%d+)");
		
		if (redVal ~= nil) then
			local success = self:Config_SetTextColor(mathceil(tonumber(redVal)), mathceil(tonumber(greenVal)), mathceil(tonumber(blueVal)));
			
			if (success == true) then
				DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_COLORS:format(redVal, greenVal, blueVal), 0.6, 0.8, 0.6);
			else
				DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_COLORS, 0.6, 0.8, 0.6);
			end
		else
			DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_COLORS, 0.6, 0.8, 0.6);
		end
		
		
	elseif (command == localization.SLASH_FONTPATH) then
		if ((argument or ""):lower() == localization.SLASH_FONTPATH_LIST) then
			DEFAULT_CHAT_FRAME:AddMessage(localization.FONT_LIST, 0.6, 0.8, 0.6);
		else
			local success = self:Config_SetFontPath(argument);
			if (success == true) then
				DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_FONT:format(argument), 0.6, 0.8, 0.6);
			else
				DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_FONT, 0.6, 0.8, 0.6);
			end
		end
		
		
	elseif (command == localization.SLASH_SIZE) then
		local success = self:Config_SetFontSize(argument);
		if (success == true) then
			DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_SIZE:format(argument), 0.6, 0.8, 0.6);
		else
			DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_SIZE, 0.6, 0.8, 0.6);
		end
		
		
	elseif (command == localization.SLASH_WIDTH) then	
		local success = self:Config_SetFrameWidth(argument);
		if (success == true) then
			DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_WIDTH:format(argument), 0.6, 0.8, 0.6);
		else
			DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_WIDTH, 0.6, 0.8, 0.6);
		end
		
		
	elseif (command == localization.SLASH_HEIGHT) then	
		local success = self:Config_SetFrameHeight(argument);
		if (success == true) then
			DEFAULT_CHAT_FRAME:AddMessage(localization.NEW_HEIGHT:format(argument), 0.6, 0.8, 0.6);
		else
			DEFAULT_CHAT_FRAME:AddMessage(localization.INVALID_HEIGHT, 0.6, 0.8, 0.6);
		end
		
		
	else
		local chatFrame = DEFAULT_CHAT_FRAME;
		local addMessage = chatFrame.AddMessage;
		
		for index = 1, 7 do
			addMessage(chatFrame, localization["COMMANDS_HELP_"..index], 0.6, 0.8, 0.6);
		end
	end
end


SlashCmdList["CUSTOMCLOCK"] = (function(msg) CustomClock:Main_SlashCommandHandler(msg); end);
SLASH_CUSTOMCLOCK1 = ("/cucl");

